@@ -5,4 +5,5 @@ Created on Fri Jul 30 13:22:34 2021
 @author: chang.sun
 """
 
-from sc_backtest import sc_backtest
\ No newline at end of file
+from .technical_analysis import *
+from .backtest import simple_test
